@@ -1,19 +1,16 @@
 #ifndef __CPUSTATUS_H
 #define __CPUSTATUS_H
 
-#if (defined(linux) || defined(HAVE_KSTAT_H))
-
-#ifdef HAVE_KSTAT_H
-#include <kstat.h>
-#include <sys/sysinfo.h>
-#endif /* have_kstat_h */
-
+#if defined(linux) || defined(HAVE_KSTAT_H) || defined(HAVE_SYSCTL_CP_TIME)
 
 #define IWM_USER   (0)
 #define IWM_NICE   (1)
 #define IWM_SYS    (2)
-#define IWM_IDLE   (3)
-#define IWM_STATES (4)
+#define IWM_INTR   (3)
+#define IWM_IOWAIT (4)
+#define IWM_SOFTIRQ (5)
+#define IWM_IDLE   (6)
+#define IWM_STATES (7)
 
 #include "ywindow.h"
 #include "ytimer.h"
@@ -23,7 +20,7 @@ public:
     CPUStatus(YWindow *aParent = 0);
     virtual ~CPUStatus();
     
-    virtual void paint(Graphics &g, int x, int y, unsigned int width, unsigned int height);
+    virtual void paint(Graphics &g, const YRect &r);
 
     virtual bool handleTimer(YTimer *t);
 
@@ -35,11 +32,12 @@ public:
 
 private:
     int **cpu;
-    long last_cpu[IWM_STATES];
+    unsigned long last_cpu[IWM_STATES];
     YColor *color[IWM_STATES];
     YTimer *fUpdateTimer;
 };
-
+#else
+#undef CONFIG_APPLET_CPU_STATUS
 #endif
 
 #endif
