@@ -63,8 +63,8 @@
 #define defgKeySysWorkspace8            '8', kfAlt+kfCtrl, "Alt+Ctrl+8"
 #define defgKeySysWorkspace9            '9', kfAlt+kfCtrl, "Alt+Ctrl+9"
 #define defgKeySysWorkspace10           '0', kfAlt+kfCtrl, "Alt+Ctrl+0"
-#define defgKeySysWorkspace11           '-', kfAlt+kfCtrl, "Alt+Ctrl+["
-#define defgKeySysWorkspace12           '=', kfAlt+kfCtrl, "Alt+Ctrl+]"
+#define defgKeySysWorkspace11           '-', kfAlt+kfCtrl, "Alt+Ctrl+bracketleft"
+#define defgKeySysWorkspace12           '=', kfAlt+kfCtrl, "Alt+Ctrl+bracketright"
 #define defgKeySysWorkspace1TakeWin     '1', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+1"
 #define defgKeySysWorkspace2TakeWin     '2', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+2"
 #define defgKeySysWorkspace3TakeWin     '3', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+3"
@@ -75,9 +75,8 @@
 #define defgKeySysWorkspace8TakeWin     '8', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+8"
 #define defgKeySysWorkspace9TakeWin     '9', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+9"
 #define defgKeySysWorkspace10TakeWin    '0', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+0"
-#define defgKeySysWorkspace11TakeWin    '-', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+["
-#define defgKeySysWorkspace12TakeWin    '=', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+]"
-#define defgKeySysWorkspace12           '=', kfAlt+kfCtrl, "Alt+Ctrl+]"
+#define defgKeySysWorkspace11TakeWin    '-', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+bracketleft"
+#define defgKeySysWorkspace12TakeWin    '=', kfAlt+kfCtrl+kfShift, "Alt+Ctrl+Shift+bracketright"
 #define defgKeySysTileVertical          XK_F2, kfAlt+kfShift, "Alt+Shift+F2"
 #define defgKeySysTileHorizontal        XK_F3, kfAlt+kfShift, "Alt+Shift+F3"
 #define defgKeySysCascade               XK_F4, kfAlt+kfShift, "Alt+Shift+F4"
